@@ -1,22 +1,23 @@
+use 5.008;
+use strict;
+use warnings;
+
 package JSON::Path;
 
-use 5.008;
-use strict qw(vars subs);
-use overload '""' => \&to_string;
-no warnings;
-
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.204';
+our $VERSION   = '0.205';
 our $Safe      = 1;
 
 use Carp;
 use JSON qw[from_json];
 use Scalar::Util qw[blessed];
-use lvalue ();
+use LV ();
 
-use Sub::Exporter -setup => {
-	exports => [qw/ jpath jpath1 jpath_map /],
-};
+use Exporter::Tiny ();
+our @ISA       = qw/ Exporter::Tiny /;
+our @EXPORT_OK = qw/ jpath jpath1 jpath_map /;
+
+use overload '""' => \&to_string;
 
 sub jpath
 {
@@ -81,7 +82,8 @@ sub _dive :lvalue
 	] unless ref $path;
 	$path = [ map { /^'(.+)'$/ ? $1 : $_ } @$path ];
 	
-	while (@$path > 1) {
+	while (@$path > 1)
+	{
 		my $chunk = shift @$path;
 		if (JSON::Path::Helper::isObject($obj))
 			{ $obj = $obj->{$chunk} }
@@ -92,22 +94,27 @@ sub _dive :lvalue
 	}
 	
 	my $chunk = shift @$path;
-	lvalue::get {
-		if (JSON::Path::Helper::isObject($obj))
-			{ $obj = $obj->{$chunk} }
-		elsif (JSON::Path::Helper::isArray($obj))
-			{ $obj = $obj->[$chunk] }
-		else
-			{ print "hUh?" }
-	}
-	lvalue::set {
-		if (JSON::Path::Helper::isObject($obj))
-			{ $obj->{$chunk} = shift }
-		elsif (JSON::Path::Helper::isArray($obj))
-			{ $obj->[$chunk] = shift }
-		else
-			{ print "huH?" }
-	}
+	
+	LV::lvalue(
+		get => sub
+		{
+			if (JSON::Path::Helper::isObject($obj))
+				{ $obj = $obj->{$chunk} }
+			elsif (JSON::Path::Helper::isArray($obj))
+				{ $obj = $obj->[$chunk] }
+			else
+				{ print "hUh?" }
+		},
+		set => sub
+		{
+			if (JSON::Path::Helper::isObject($obj))
+				{ $obj->{$chunk} = shift }
+			elsif (JSON::Path::Helper::isArray($obj))
+				{ $obj->[$chunk] = shift }
+			else
+				{ print "huH?" }
+		},
+	);
 }
 
 sub paths
@@ -138,14 +145,18 @@ sub set
 sub value :lvalue
 {
 	my ($self, $object) = @_;
-	lvalue::get {
-		my ($value) = $self->get($object);
-		return $value;
-	}
-	lvalue::set {
-		my $value = shift;
-		$self->set($object, $value, 1);
-	}
+	LV::lvalue(
+		get => sub
+		{
+			my ($value) = $self->get($object);
+			return $value;
+		},
+		set => sub
+		{
+			my $value = shift;
+			$self->set($object, $value, 1);
+		},
+	);
 }
 
 sub values
@@ -163,6 +174,7 @@ sub map
 	{
 		++$count;
 		my $value = do {
+			no warnings 'numeric';
 			local $_ = _dive($object, $path);
 			local $. = $path;
 			scalar $coderef->();
@@ -180,7 +192,7 @@ BEGIN {
 	no warnings;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.204';
+	our $VERSION   = '0.205';
 	
 	use Carp;
 	use Scalar::Util qw[blessed];
